#!/usr/bin/env python3
"""Setup script for TuskTsk package."""

from setuptools import setup, find_packages
from pathlib import Path

here = Path(__file__).parent.resolve()

setup(
    name="tusktsk",
                    version="2.0.5",
    description="TuskTsk - Configuration with a Heartbeat. Enhanced with 140+ CLI commands including binary operations and AI management!",
    author="Cyberboost LLC",
    author_email="packages@tuskt.sk",
    url="https://tuskt.sk",
    license="MIT",
                    long_description=(here / "README_PYPI.md").read_text(encoding="utf-8"),
    long_description_content_type="text/markdown",
    package_dir={"": "."},
    packages=find_packages(where=".", exclude=[
        "z_archive*",
        "tests*",
        "temp_*",
        "build*",
        "dist*",
        "*.egg-info*",
        "venv*",
        ".pytest_cache*",
        ".tsk_cache*",
        ".claude*",
        "commandsneeded*",
        "assets*",
        "summaries*"
    ]),
    python_requires=">=3.8, <4",
    install_requires=[
        "msgpack>=1.0.0",
        "watchdog>=2.0.0",
        "psutil>=5.8.0",
        "colorama>=0.4.4",
        "click>=8.0.0",
        "pyyaml>=6.0",
        "jinja2>=3.0.0",
        "requests>=2.25.0",
        "cryptography>=3.4.0",
        "python-dotenv>=0.19.0",
        "sqlalchemy>=1.4.0",
        "alembic>=1.7.0",
        "redis>=4.0.0",
        "celery>=5.2.0",
        "fastapi>=0.68.0",
        "uvicorn>=0.15.0",
        "pydantic>=1.8.0",
        "httpx>=0.23.0",
        "websockets>=10.0",
        "aiofiles>=0.7.0",
        "asyncio-mqtt>=0.11.0",
        "prometheus-client>=0.12.0",
        "structlog>=21.5.0",
        "tenacity>=8.0.0",
        "pydantic-settings>=2.0.0",
        "python-multipart>=0.0.5",
        "passlib>=1.7.4",
        "python-jose>=3.3.0",
        "bcrypt>=3.2.0",
        "email-validator>=1.1.3",
        "pillow>=8.3.0",
        "opencv-python>=4.5.0",
        "numpy>=1.21.0",
        "pandas>=1.3.0",
        "matplotlib>=3.4.0",
        "seaborn>=0.11.0",
        "scikit-learn>=1.0.0",
        "tensorflow>=2.6.0",
        "torch>=1.9.0",
        "transformers>=4.11.0",
        "openai>=0.27.0",
        "anthropic>=0.3.0",
        "langchain>=0.0.200",
        "chromadb>=0.3.0",
        "sentence-transformers>=2.2.0",
        "faiss-cpu>=1.7.0",
        "tiktoken>=0.3.0",
        "openai-whisper>=20230314",
        "elevenlabs>=0.2.0",
        "stability-sdk>=0.8.0",
        "diffusers>=0.14.0",
        "accelerate>=0.20.0",
        "bitsandbytes>=0.39.0",
        "optimum>=1.8.0",
        "peft>=0.4.0",
        "trl>=0.4.0",
        "datasets>=2.10.0",
        "huggingface-hub>=0.13.0",
        "gradio>=3.30.0",
        "streamlit>=1.22.0",
        "dash>=2.6.0",
        "plotly>=5.10.0",
        "bokeh>=2.4.0",
        "altair>=4.2.0",
        "vega-lite>=5.0.0",
        "d3blocks>=1.3.0",
        "networkx>=2.6.0",
        "igraph>=0.9.0",
        "community>=0.15.0",
        "python-louvain>=0.15.0",
        "scipy>=1.7.0",
        "sympy>=1.9.0",
        "numba>=0.56.0",
        "cython>=0.29.0",
        "mypy>=0.950",
        "black>=22.0.0",
        "isort>=5.10.0",
        "flake8>=4.0.0",
        "pylint>=2.12.0",
        "bandit>=1.7.0",
        "safety>=1.10.0",
        "pre-commit>=2.19.0",
        "tox>=3.24.0",
        "pytest>=6.2.0",
        "pytest-cov>=3.0.0",
        "pytest-asyncio>=0.18.0",
        "pytest-mock>=3.6.0",
        "pytest-xdist>=2.4.0",
        "coverage>=6.0.0",
        "mutmut>=2.2.0",
        "hypothesis>=6.50.0",
        "faker>=13.0.0",
        "factory-boy>=3.2.0",
        "responses>=0.20.0",
        "httpretty>=1.1.0",
        "vcrpy>=4.2.0",
        "betamax>=0.8.0",
        "freezegun>=1.2.0",
        "time-machine>=2.6.0",
        "pytest-freezegun>=0.4.0",
        "pytest-timeout>=2.0.0",
        "pytest-repeat>=0.9.0",
        "pytest-rerunfailures>=10.2.0",
        "pytest-html>=3.1.0",
        "pytest-json-report>=1.5.0",
        "allure-pytest>=2.9.0",
        "locust>=2.8.0",
        "pytest-benchmark>=3.4.0",
        "memory-profiler>=0.60.0",
        "psutil>=5.8.0",
        "py-spy>=0.3.0",
        "scalene>=1.5.0",
        "pyinstrument>=4.0.0",
        "line-profiler>=3.4.0",
        "objgraph>=3.5.0",
        "guppy3>=3.1.0",
        "pympler>=0.9.0",
        "tracemalloc>=0.1.0",
        "snakeviz>=2.1.0",
        "pycallgraph>=1.0.0",
        "memory-profiler>=0.60.0",
        "psutil>=5.8.0",
        "py-spy>=0.3.0",
        "scalene>=1.5.0",
        "pyinstrument>=4.0.0",
        "line-profiler>=3.4.0",
        "objgraph>=3.5.0",
        "guppy3>=3.1.0",
        "pympler>=0.9.0",
        "tracemalloc>=0.1.0",
        "snakeviz>=2.1.0",
        "pycallgraph>=1.0.0"
    ],
    extras_require={
        "dev": [
            "pytest>=6.2.0",
            "black>=22.0.0",
            "flake8>=4.0.0",
            "mypy>=0.950",
            "pre-commit>=2.19.0",
        ],
        "ai": [
            "openai>=0.27.0",
            "anthropic>=0.3.0",
            "langchain>=0.0.200",
            "transformers>=4.11.0",
            "torch>=1.9.0",
            "tensorflow>=2.6.0",
        ],
        "web": [
            "fastapi>=0.68.0",
            "uvicorn>=0.15.0",
            "streamlit>=1.22.0",
            "gradio>=3.30.0",
        ],
        "data": [
            "pandas>=1.3.0",
            "numpy>=1.21.0",
            "scikit-learn>=1.0.0",
            "matplotlib>=3.4.0",
        ],
    },
    entry_points={
        "console_scripts": [
            "tsk=tusktsk.cli:main",
            "tusktsk=tusktsk.cli:main",
        ],
    },
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: System :: Systems Administration",
        "Topic :: Utilities",
    ],
    keywords="configuration, database, cli, binary, ai, management",
    project_urls={
        "Bug Reports": "https://github.com/tuskt/sdk/issues",
        "Source": "https://github.com/tuskt/sdk",
        "Documentation": "https://docs.tuskt.sk",
    },
    include_package_data=True,
    zip_safe=False,
)